%define oname       FreeImage
%define srcver      %(echo %{version} | tr -d .)

%define major       3
%define libname     %mklibname %{name} %{major}
%define develname   %mklibname %{name} -d

Name:           freeimage
# (akien) We used to have version 3.15.4 badly named 3.154,
# so an epoch was needed to transition to 3.17.0.
Epoch:          1
Version:        3.18.0
Release:        %mkrel 4
Summary:        Multi-format image decoder library
# freeimage is triple-licensed, see
# http://freeimage.sourceforge.net/license.html
# https://lists.fedoraproject.org/pipermail/legal/2013-October/002271.html
License:        GPLv2 or GPLv3 or MPLv1.0
Group:          System/Libraries
URL:            http://freeimage.sourceforge.net/
Source0:        http://downloads.sourceforge.net/freeimage/%{oname}%{srcver}.zip

# Patches synced with Debian (they do a better job than Fedora on freeimage)
Patch0:         Disable-vendored-dependencies.patch
Patch1:         Use-system-dependencies.patch
Patch2:         Fix-macro-redefinition-for-64-bit-integer-types.patch
Patch3:		Fix-compatibility-with-system-libpng.patch
Patch4:		Disable-usage-of-HTML-timestamps-in-doxygen.patch
Patch5:		Disable-testing-of-JPEG-transform.patch
Patch6:		Disable-testing-of-JXR-MemIO.patch
Patch7:         Fix-encoding-of-fi-header.patch
Patch8:		Fix-libraw-compilation.patch

# Fix trying to change file ownership
Patch10:        FreeImage-3.17.0-mga-makeinstall.patch

# Patch from Gentoo to fix build error in JPEG plugin
Patch11:	freeimage-3.15.4-rename-static.patch

# Backport fixes for CVE-2019-12211 and 2019-12213
# https://sourceforge.net/p/freeimage/svn/1825/tree//FreeImage/trunk/Source/FreeImage/PluginTIFF.cpp?diff=5a0ca8dd5a4a1f6b3942a079:1824
Patch12:	CVE-2019-12211_2019-12213.patch

BuildRequires:  jxrlib-devel
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libmng)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(libpng)
BuildRequires:  pkgconfig(libraw)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(OpenEXR)

%description
FreeImage is an Open Source library project for developers who would
like to support popular graphics image formats like PNG, BMP, JPEG,
TIFF and others as needed by today's multimedia applications.
FreeImage is easy to use, fast, multithreading safe and cross-platform.

#----------------------------------------------------------------------

%package -n %{libname}
Summary:        Multi-format image decoder library
Group:          System/Libraries

%description -n %{libname}
FreeImage is an Open Source library project for developers who would
like to support popular graphics image formats like PNG, BMP, JPEG,
TIFF and others as needed by today's multimedia applications.
FreeImage is easy to use, fast, multithreading safe, compatible with
all 32-bit versions of Windows, and cross-platform (works both with
Linux and Mac OS X).

#----------------------------------------------------------------------

%package -n %{develname}
Summary:        Development tools for programs using FreeImage
Group:          Development/C
Requires:       %{libname} = %{epoch}:%{version}-%{release}
Provides:       %{name}-devel = %{epoch}:%{version}-%{release}

%description -n %{develname}
This package contains the header files and libraries needed for
developing programs using the FreeImage library.

#----------------------------------------------------------------------

%prep
%autosetup -p1 -n %{oname}

# Remove included libs to make sure these don't get used during compilation
rm -rf Source/Lib* Source/OpenEXR Source/ZLib

%build
%global optflags %{optflags} -fPIC
%set_build_flags

sh ./gensrclist.sh
%make_build

%install
%make_install \
  INCDIR=%{buildroot}%{_includedir} \
  INSTALLDIR=%{buildroot}%{_libdir}

# We don't package static libs
rm -f %{buildroot}%{_libdir}/lib%{name}.a

%files -n %{libname}
%doc Whatsnew.txt license-*.txt README.linux
%{_libdir}/lib%{name}.so.%{major}
%{_libdir}/lib%{name}-%{version}.so

%files -n %{develname}
%{_includedir}/%{oname}.h
%{_libdir}/lib%{name}.so


%changelog
* Wed Sep 09 2020 daviddavid <daviddavid> 1:3.18.0-4.mga8
+ Revision: 1623987
- add debian patch  to fix build with new libraw 0.20
+ zezinho <zezinho>
- rebuild against libraw20

* Tue Feb 18 2020 umeabot <umeabot> 1:3.18.0-3.mga8
+ Revision: 1541460
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Fri Dec 27 2019 ns80 <ns80> 1:3.18.0-2.mga8
+ Revision: 1470712
- bump rel

* Fri Dec 27 2019 ns80 <ns80> 1:3.18.0-1.1.mga8
+ Revision: 1470710
- add patch from Fedora for CVE-2019-12211 and 2019-12213 (mga#25967)

* Sun Jan 27 2019 luigiwalser <luigiwalser> 1:3.18.0-1.mga7
+ Revision: 1361505
- add patch from gentoo to fix build error in JPEG plugin
- 3.18.0
- resync patches with debian

* Mon Oct 15 2018 daviddavid <daviddavid> 1:3.17.0-7.mga7
+ Revision: 1320484
- rebuild for new openexr 2.3.0

* Thu Sep 06 2018 daviddavid <daviddavid> 1:3.17.0-6.mga7
+ Revision: 1257504
- rebuild for new libraw 0.19.0

* Sun May 27 2018 wally <wally> 1:3.17.0-5.mga7
+ Revision: 1232412
- rebuild for openexr 2.2.1

* Tue Jan 09 2018 wally <wally> 1:3.17.0-4.mga7
+ Revision: 1191924
- rebuild for new ilmbase

* Thu Aug 17 2017 sander85 <sander85> 1:3.17.0-3.mga7
+ Revision: 1141357
- Rebuild for new libwebp

* Fri Jan 27 2017 akien <akien> 1:3.17.0-2.mga6
+ Revision: 1083622
- Switch to Debian patches for library unbundling
  (Fedora patches caused underlinking)

* Sun Jan 22 2017 akien <akien> 1:3.17.0-1.mga6
+ Revision: 1082978
- Version 3.17.0
- Add an epoch to fix version (3.154 -> 3.15.4)

* Wed Dec 28 2016 wally <wally> 3.154-13.mga6
+ Revision: 1078509
- rebuild for ARM

* Wed Dec 28 2016 neoclust <neoclust> 3.154-12.mga6
+ Revision: 1078463
- Rebuild for new libraw

* Mon Oct 31 2016 akien <akien> 3.154-11.mga6
+ Revision: 1064385
- Fix CVE-2015-3885: integer overflow in the ljpeg_start function
- Fix CVE-2016-5864: apply patch from wheezy-security (mga#19547)

* Thu Jun 16 2016 pterjan <pterjan> 3.154-10.mga6
+ Revision: 1021629
- Add -fPIC

* Sun Dec 27 2015 daviddavid <daviddavid> 3.154-9.mga6
+ Revision: 916156
- rebuild for new libraw 0.17.1

* Fri Sep 04 2015 akien <akien> 3.154-8.mga6
+ Revision: 872851
- Update bundled libtiff to 4.0.4, fixing several security issues

* Fri Sep 04 2015 akien <akien> 3.154-7.mga6
+ Revision: 872795
- Update to maintenance version 3.15.4
- Unbundle all system libs (except libtiff4, private defs are used in the tiff plugin)
  o libjpeg, libmng, libopenexr, libopenjpeg, libpng, zlib unbundled (Patch0)
  o private jpeg lib unbundled by dropping support for JPEGTransform (Patch1)
- Add patches synced with Debian to fix various issues (Patch2 to 5)
+ luigiwalser <luigiwalser>
- add upstream patch to fix CVE-2015-0852

* Sat Aug 22 2015 akien <akien> 3.153-6.mga6
+ Revision: 868034
- Rebuild for gcc 5.2.1

* Wed Oct 15 2014 umeabot <umeabot> 3.153-5.mga5
+ Revision: 744657
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.153-4.mga5
+ Revision: 679340
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.153-3.mga4
+ Revision: 504640
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 3.153-2.mga3
+ Revision: 350906
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jun 10 2012 fwang <fwang> 3.153-1.mga3
+ Revision: 259241
- new version 3.15.3

* Sat Oct 01 2011 fwang <fwang> 3.151-1.mga2
+ Revision: 150743
- new version 3.151
- new version 3.15.1
  build with internal libs for now, patch on syslibs need to be revised
- rebuild for new libpng

* Mon Feb 28 2011 supp <supp> 3.110-9.mga1
+ Revision: 61341
- imported package freeimage

